@@ -13,7 +13,10 @@
 
 
 AdvCorrectionAbsorptionDNA :: AdvCorrectionAbsorptionDNA(void){
-
+  if (!(isReady())) {
+    UtsusemiError("AdvCorrectionAbsorptionDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
   // read sample data
 
   //std::string filepath = getenv("HOME");
@@ -71,7 +74,10 @@ AdvCorrectionAbsorptionDNA :: AdvCorrectionAbsorptionDNA(void){
 }
 
 AdvCorrectionAbsorptionDNA :: AdvCorrectionAbsorptionDNA(std::string filepath){
-
+  if (!(isReady())) {
+    UtsusemiError("AdvCorrectionAbsorptionDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
   wallInfo.initialize();
   sampleInfo.initialize();
   std::cout << "database_filepath = " <<filepath <<std::endl;
