@@ -10,7 +10,10 @@
 
 
 AdvDetectorManagerDNA:: AdvDetectorManagerDNA(void){
-
+  if (!(isReady())) {
+    UtsusemiError("AdvDetectorManagerDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
         //std::string filepath = getenv("HOME");
   std::string filepath = UtsusemiEnvGetUserDir();
   std::string filename = "detector_data.dat";
@@ -70,7 +73,10 @@ AdvDetectorManagerDNA:: AdvDetectorManagerDNA(void){
 }
 
 AdvDetectorManagerDNA:: AdvDetectorManagerDNA(std::string filepath){
-
+  if (!(isReady())) {
+    UtsusemiError("AdvDetectorManagerDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
   wallInfo.initialize();
   detectorInfo.initialize();
 
