@@ -10,7 +10,10 @@
 
 
 AdvMultiScatteringDNA :: AdvMultiScatteringDNA(void){
-
+  if (!(isReady())) {
+    UtsusemiError("AdvMultiScatteringDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
   // read sample data
 
         //std::string filepath = getenv("HOME");
@@ -61,7 +64,10 @@ AdvMultiScatteringDNA :: AdvMultiScatteringDNA(void){
 }
 
 AdvMultiScatteringDNA :: AdvMultiScatteringDNA(std::string filepath){
-
+  if (!(isReady())) {
+    UtsusemiError("AdvMultiScatteringDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
   //filename="/home/dnaadmin/00Install/work.DNA/correction/sample_data.dat";
   wallInfo.initialize();
   sampleInfo.initialize();
