@@ -58,26 +58,26 @@ def CheckT0bUpdate(runNo):
                     os.system("rm %s"%t0b)
     ## <-- [20150311]YI
     # --> TI [20140403]
-    
+
 ########################################
 def GetHistogramBaseSAS( runNo="0", Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlice="-1 -1", frameBoundary="0.0", isTimeFoc=False, SolAngCor=True, paramFiles="- -", isPH=False, PHrange="0 4096" ):
     """
     Base Function to Load EventData to produce histogram for SAS
     GetHistogramBaseSAS( runNo=0, Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlice="-1 -1", frameBoundary="0.0", isTimeFoc=False, SolAngCor=True, paramFiles="- -", isPH=False, PHrange="0 4096" )
-    
+
     @param runNo     (string)     Run Number
-    @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof, d, ene]
+    @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof, d, rd, ene]
     @param Bank      (string)  "SM"...  Monitors by "MON1" or "MON2"
     @param TimeSlice (string)  "startTime endTime" separated with space: "-1 -1" means no-setting.
     @param frameBoundary (string) "frameBoundary" or "frameBoundary TofMask_min TofMask_max"
     @param isTimeFoc (bool)    True or False
     @param SolAngCor  (bool)    True or False for Solid Angle Correction
     @param paramFiles (string) "WiringInfo DetectorInfo"
-    @param isPH (bool) 
+    @param isPH (bool)
     @param PHrange (string)
     @retval DAT (ElementContainerMatrix)
     """
-    
+
     ## Check Bank
     detType=""
     mode_no=0 #"PSD"
@@ -206,7 +206,7 @@ def GetHistogramBaseSAS( runNo="0", Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlic
             raise UserWarning("runNos are invalid")
     elif type(runNo)==int:
         runNo_list = [ str(runNo) ]
-    
+
     ## Check T0b
     runNo = ""
     for a_runNo in runNo_list:
@@ -220,7 +220,7 @@ def GetHistogramBaseSAS( runNo="0", Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlic
             #ConvertFromRPMTK2Psd( int(a_runNo), DaqId, 0, "SAS03")
             ConvertFromRPMTK2Psd(int(a_runNo), DaqId, 0, "SAS03", mode_no, RPMT_LLDHLD, RPMT_COI, dfile_found_path)
     runNo = runNo[:-1]
-    
+
     ## Make Parameter File to Create Histogram
     GNH = mu.UtsusemiGetNeunetHistogram()
 
@@ -248,18 +248,20 @@ def GetHistogramBaseSAS( runNo="0", Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlic
         conv_params="tof,%g,%g,%g"%(float(p_list[0]),float(p_list[1]),float(p_list[2]))
     elif AxType=="d":
         conv_params="d,%g,%g,%g"%(float(p_list[0]),float(p_list[1]),float(p_list[2]))
+    elif AxType == "rd":
+        conv_params="rd,%g,%g,%g"%(float(p_list[0]),float(p_list[1]),float(p_list[2]))
     elif AxType=="ene":
         conv_params="energy,%g,%g,%g"%(float(p_list[0]),float(p_list[1]),float(p_list[2]))
     else:
-        raise UserWarning("param error about conv type")
+        raise UserWarning("param error about conv type ({})".format(AxType))
 
     #print( "Conv Params="+conv_params )
     #print( "DetType="+detType )
     #print( "Bank="+Bank )
-    
+
     if not GNH.SetConversionParameter( conv_params ):
         raise UserWarning("Conv_params is invalid."+conv_params)
-    
+
     if not GNH.SetDetParam( detType ):
         if detType!="RPMTo":
             raise UserWarning("DetType is invalid."+detType)
@@ -366,20 +368,20 @@ def GetHistogramBaseSAS( runNo="0", Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlic
     if len(dat_list)==1:
         return dat_list[0]
     return dat_list
-    
+
 ########################################
 def GetHistogramRPMT( runNo, wfile, dfile, timeslice=[] ):
     """
     Load EventData to produce histogram
     GetHistogramSAS( runNo=0, AxType="lambda", Xrange="0.7 7.7 0.05", Bank="SM", TimeSlice="-1 -1", frameBoundary=0.0, isTimeFoc=False )
-    
+
     @param runNo     (int)     Run Number
     @retval DAT (ElementContainerMatrix)
     """
-        
+
     dataPath = mu.UtsusemiEnvGetDataDir()
     t0Path = ""
-    
+
     if type(runNo)==int:
         runNo_list = [ str(runNo) ]
     elif type(runNo)==str:
@@ -392,36 +394,36 @@ def GetHistogramRPMT( runNo, wfile, dfile, timeslice=[] ):
     v_runNo = Manyo.MakeUInt4Vector()
     for a_runNo in runNo_list:
         v_runNo.append( int(a_runNo) )
-    
+
     tt=mu.UtsusemiEventDataConverterRPMT()
     tt.LoadParamFiles( wfile, dfile )
     tt.SetHistAllocation()
-    
+
     dat=Manyo.ElementContainerMatrix()
     tt.SetElementContainerMatrix( dat, v_runNo, dataPath, t0Path )
-    
+
     Phi=mu.PhiCalculation(dat,0.2,0.2,0.2)
     Phi.CalcPhi()
     del Phi
-    
+
     dat2 = Manyo.ElementContainerMatrix(dat.PutHeader())
     hh_dat2 = dat2.PutHeaderPointer()
-    
+
     vid = Manyo.MakeInt4Vector()
     vid.push_back(SASBankDic["RPMT"])
     vnm = Manyo.MakeStringVector()
     vnm.push_back("RPMT")
     vbs = Manyo.MakeInt4Vector()
     vbs.push_back(820)
-    
+
     hh_dat2.Add("BANKIDLIST", vid )
     hh_dat2.Add("BANKNAMELIST", vnm )
     hh_dat2.Add("BANKSIZELIST", vbs )
-    
+
     num_of_eca = dat.PutSize()
     for i in range(num_of_eca):
         eca = dat(num_of_eca-1-i)
-        
+
         hh = eca.PutHeader()
         #DETID=hh.PutInt4("DETID")
         #hh.OverWrite("DETID", num_of_eca-1-DETID)
@@ -450,7 +452,7 @@ def GetHistogramSAS( runNo=0, Xrange="0.7 7.6 0.1 dL", Bank="SM", TimeSlice="-1
     """
     Load EventData to produce histogram
     GetHistogramSAS( runNo=0, AxType="lambda", Xrange="0.7 7.7 0.05", Bank="SM", TimeSlice="-1 -1", frameBoundary=0.0, isTimeFoc=False )
-    
+
     @param runNo     (int)     Run Number
     @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof]
     @param Bank      (string)  "SM"...  Monitors by "MON1" or "MON2"
@@ -468,12 +470,12 @@ def GetMonHistSAS( runNo="0", MonNo=1, AxType="lambda", Xrange="0.7 7.6 0.1", Mo
     """
     Load EventData to produce histogram of monitors
     GetMonHistSAS( runNo="0", MonNo=1, AxType="lambda", Xrange="0.7 7.7 0.05", MonIndex=0, TimeSlice="-1 -1", frameBoundary="0.0", CalibEffi=True, RPMTarea="150 150 152 152", RPMTeffiParam="0.10516 0.04838" )
-    
+
     @param runNo     (string)     Run Number
     @param MonNo     (int)     Monitor Number 1 (up-stream), 2 (down-stream), 3 or 10
-    @param AxType    (string)  Type must be "tof', "lambda", "lamda2" or "d"
+    @param AxType    (string)  Type must be "tof', "lambda", "lamda2", "d" or "rd"
     @param Xrange    (string)  "startX endX widthX" separated with space (not comma)
-    @param MonIndex  (int)     
+    @param MonIndex  (int)
     @param TimeSlice (string)  "startTime endTime" separated with space: "-1 -1" means no-setting.
     @param frameBoundary (string) "frameBoundary" or "frameBoundary TofMask_min TofMask_max"
     @param CalibEffi (bool)    Monitor-detector efficiency calibration
@@ -504,6 +506,8 @@ def GetMonHistSAS( runNo="0", MonNo=1, AxType="lambda", Xrange="0.7 7.6 0.1", Mo
         Xrange += " dl/l"
     elif ax_axis=="d":
         Xrange += " d"
+    elif ax_axis=="rd":
+        Xrange += " rd"
     else:
         raise UserWarning("AxType is invalid %s"%(AxType))
 
@@ -554,7 +558,7 @@ def GetPulseHeightSAS( runNo="0", Xrange="0 10000 10", Bank="SM", TimeSlice="-1
     """
     Make Pulse Height data of EventData
     GetPulseHeightSAS( runNo=0, Xrange="0 10000 10", Bank="SM", TimeSlice="-1 -1", paramFiles="- -" ):
-    
+
     @param runNo     (string)     Run Number
     @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof]
     @param Bank      (string)  "SM"...  Monitors by "MON1" or "MON2"
@@ -580,7 +584,7 @@ def GetPulseHeightSAS( runNo="0", Xrange="0 10000 10", Bank="SM", TimeSlice="-1
         hh = ret(i).PutHeaderPointer()
         pId_list.append( hh.PutInt4("DetId") )
     pId_list.sort()
-    
+
     eca = Manyo.ElementContainerArray(dat.PutHeader())
     SIH = Manyo.SearchInHeader()
     SIH.SetTarget( ret )
@@ -600,23 +604,23 @@ def GetPulseHeightSAS( runNo="0", Xrange="0 10000 10", Bank="SM", TimeSlice="-1
             print("serching failed at pId=",pId)
     del SIH
     del dat
-    
+
     return eca
 
-    
+
 ########################################
 def GetMonHistByPhSAS( runNo="0", MonNo=1, Xrange="0.0 40000.0 10.0 tof", phRange="0 10000", MonIndex=0, TimeSlice="-1 -1", frameBoundary=0.0, CalibEffi=True ):
     """
     Load EventData to produce histogram of monitors limited by pulse height
     GetMonHistByPhSAS( runNo="0", MonNo=1, Xrange="0.0 40000.0 10.0 tof", phRange="0 10000", MonIndex=0, TimeSlice="-1 -1", frameBoundary=0.0, CalibEffi=True )
-    
+
     @param runNo     (int)     Run Number
     @param MonNo     (int)     Monitor Number 1 (up-stream) or 2 (down-stream)
     @param Xrange    (string)  "startX endX widthX type" separated with space (not comma) : type=[dL, dL/L, tof]
-    @param phRange   (string)  "lld hld" 
+    @param phRange   (string)  "lld hld"
     @param MonIndex  (int)     0.. digital  1.. analog
     @param TimeSlice (string)  "startTime endTime" separated with space: "-1 -1" means no-setting.
-    @param frameBoundary (float) 
+    @param frameBoundary (float)
     @param CalibEffi (bool)    Monitor-detector efficiency calibration
     @retval EC (ElementContainer)
     """
@@ -636,27 +640,27 @@ def GetMonHistByPhSAS( runNo="0", MonNo=1, Xrange="0.0 40000.0 10.0 tof", phRang
     key_kc = "KICKERCOUNT"
     kick_count = dat.PutHeader().PutInt4(key_kc)
     ec.AddToHeader(key_kc,kick_count)
-    
+
     # Monitor Detector Efficienty Calibration
     if (CalibEffi):
         p_N2 = 0.465  #[atm]
         t_Mon = 12   # thickness of monitor [mm]
         t_Al  = 0.5  # thickness of Al window [mm]
-        
+
         dec = ms.DetectorEffiCorrection()
         dec.N2MonEffiCorrection( ec, p_N2, t_Mon, t_Al )
         del dec
 
-    
-    
+
+
     return ec
 
-#########################################                                
+#########################################
 def MergeSMSC4DetMap(dat):
-    """ 
-    Merge Data SM and SC bank into one ElementContainerMatrix 
+    """
+    Merge Data SM and SC bank into one ElementContainerMatrix
     to plot using DetectMap
-    @param dat  (ElementContainerMatrix) 
+    @param dat  (ElementContainerMatrix)
     @retval ElementContainerMatrix
     """
     SIH = Manyo.SearchInHeader( dat )
@@ -686,7 +690,7 @@ def MergeSMSC4DetMap(dat):
                 for i in range(25):
                     matrix[24-i][pixel_no] =(vv[0],i)
             pixel_no+=1
-    
+
     ##SC_Left
     det_no = 7
     for det_id in range( 928, 936 ):
@@ -710,8 +714,8 @@ def MergeSMSC4DetMap(dat):
                     #matrix[det_no][65-i] = (vv[0],i+8)
                     matrix[det_no][65-i] =(vv[0],15-i)
             det_no=det_no-1
-        
-    
+
+
     ec_tmp = dat(0,0)
     xx=ec_tmp.PutXList()
     yy=ec_tmp.PutYList()
@@ -728,7 +732,7 @@ def MergeSMSC4DetMap(dat):
     ec_empty.Add(ykey,yy_zero)
     ec_empty.Add(ekey,ee_zero)
     ec_empty.SetKeys(xkey,ykey,ekey)
-    
+
     hh=dat.PutHeader()
     hh.Erase("BANKIDLIST")
     hh.Erase("BANKSIZELIST")
@@ -746,7 +750,7 @@ def MergeSMSC4DetMap(dat):
     v_name[0]="SM16"
     v_name[1]="SC"
     v_name[2]="SM14"
-    """    
+    """
     v_id=Manyo.MakeInt4Vector(1)
     v_id[0]=0
     v_size=Manyo.MakeInt4Vector(1)
@@ -760,7 +764,7 @@ def MergeSMSC4DetMap(dat):
 
     ecm = Manyo.ElementContainerMatrix( hh )
 
-    
+
     # SM16
     for psd_no in range(112):
         psd_id = 280 + psd_no
@@ -773,7 +777,7 @@ def MergeSMSC4DetMap(dat):
                 hh.Erase("INDEXINBANK")
                 hh.Add("BANKID",0)
                 hh.Add("INDEXINBANK", psd_no)
-                
+
                 ecm.Add( eca )
                 del eca
             else:
@@ -785,7 +789,7 @@ def MergeSMSC4DetMap(dat):
                 hh.Add("INDEXINBANK", psd_no )
                 ecm.Add(eca)
                 del eca
-    
+
     # SC
     det_no = 112
     for a_psd in matrix:
@@ -814,7 +818,7 @@ def MergeSMSC4DetMap(dat):
             hh.Add("MASKED", 0 )
         ecm.Add(eca)
         det_no +=1
-    
+
     # SM14
     for psd_no in range(144):
         psd_id = 392 + psd_no
@@ -838,21 +842,21 @@ def MergeSMSC4DetMap(dat):
                 hh.Add("INDEXINBANK", 112+25+psd_no)
                 ecm.Add(eca)
                 del eca
-    
+
     del SIH
     return ecm
 
 def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
-    """ 
-    Merge Data SM and SC bank into one ElementContainerMatrix 
+    """
+    Merge Data SM and SC bank into one ElementContainerMatrix
     to plot using DetectMap
-    @param dat  [Def:DAT] (ElementContainerMatrix) 
+    @param dat  [Def:DAT] (ElementContainerMatrix)
     @param PsdRange
     @param PixelRange
     @retval None
     """
     import Manyo
-    
+
     psd_range_list=PsdRange.split(" ")
     if len(psd_range_list)!=2:
         raise UserWarning("PsdRange is invalid #1")
@@ -864,7 +868,7 @@ def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
         raise UserWarning("PixelRange is invalid")
     pixel1 = int(pixel_range_list[0])
     pixel2 = int(pixel_range_list[1])
-    
+
     SIH = Manyo.SearchInHeader()
     SIH.SetTarget( dat )
     eca1 = None
@@ -877,10 +881,10 @@ def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
         rslt = SIH.PutResultIndex(0)
         if rslt.size()!=0:
             eca2 = dat.PutPointer(rslt[0])
-    
+
     if eca1==None or eca2==None:
         raise UserWarning("PsdRange is invalid #2")
-    
+
     import math
     for i in range( eca1.PutSize() ):
         ec1 = eca1(i)
@@ -888,7 +892,7 @@ def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
         keyX = ec1.PutXKey()
         keyY = ec1.PutYKey()
         keyE = ec1.PutEKey()
-        
+
         yy1 = ec1.PutY()
         yy2 = ec2.PutY()
         ee1 = ec1.PutE()
@@ -902,12 +906,12 @@ def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
         ec1.Replace( keyE, ee_ave )
         ec2.Replace( keyY, yy_ave )
         ec2.Replace( keyE, ee_ave )
-        
+
         ec1.SetKeys( keyX, keyY, keyE )
         ec2.SetKeys( keyX, keyY, keyE )
 
     #del SIH
-    
+
     for i in range( dat.PutSize() ):
         if dat(i).PutSize()==0:
             continue
@@ -928,7 +932,7 @@ def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
         keyX = ec1.PutXKey()
         keyY = ec1.PutYKey()
         keyE = ec1.PutEKey()
-        
+
         yy1 = ec1.PutY()
         yy2 = ec2.PutY()
         ee1 = ec1.PutE()
@@ -942,7 +946,7 @@ def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
         ec1.Replace( keyE, ee_ave )
         ec2.Replace( keyY, yy_ave )
         ec2.Replace( keyE, ee_ave )
-        
+
         ec1.SetKeys( keyX, keyY, keyE )
         ec2.SetKeys( keyX, keyY, keyE )
 
@@ -952,7 +956,7 @@ def RPMTRemoveCenterLine( dat, PsdRange="200 201", PixelRange="198 199" ):
 def ConvertFromRPMTK2Psd(runNo, daqId, modNo=0, dataPath=None, modeNo=5, rpmtPrm=[128,1024,128,1024], lmtCoi=32, dfile=""):
     """
     Convert event data for RPMT of KEK to ones for PSD
-    
+
     @param runNo (int) runNo
     @param daqId (int) Daq Id for RPMT of KEK
     @param dataPath (string) Data path
@@ -1616,7 +1620,7 @@ def GetSumPixelArea( dat, PixelRange ):
 def GetHistInelaSAS( runNo="0", Bank="SM", Ei=10.0, Erange="-5 5", dHW=0.1):
     """
     Histogram Creation for inelastic scattering on SAS
-    
+
     @param runNo     (string)  Run Number "10,11,12"
     @param Bank      (string)  "SM"...  Monitors by "MON1" or "MON2"
     @param Ei        (float)   Incident energy
