@@ -33,7 +33,7 @@ DATList=None
 #########################################
 def GetNeunetHistSAS(runNo="0",HistParam="tof,0,40000,100",DetParam="psd",DetRange="All",TimeRange="All",FrameInfo="None",MaskInfo="NoFile",CaseInfo="None",BGInfo="TimeDep:None",TofShift="None",AnaMode="0",ParamFiles="-,-",SolAngCor=False):
     """
-    Convert Event data of NEUNET to Histogram 
+    Convert Event data of NEUNET to Histogram
     GetNeunetHist(runNo="197,198",
                   HistParam="tof,0,40000,100",
                   DetParam="psd",
@@ -54,22 +54,24 @@ def GetNeunetHistSAS(runNo="0",HistParam="tof,0,40000,100",DetParam="psd",DetRan
         TOF
            delta-TOF const :  tof,<min_tof>,<max_tof>,<delta_tof>
            d-TOF/TOF const : rtof,<min_tof>,<max_tof>,<racio>
-       
+
         TOF with time forcusing
            delta-TOF const : tf-tof,<min_tof>,<max_tof>,<delta_tof>
            d-TOF/TOF const : tf-rtof,<min_tof>,<max_tof>,<racio>
-    
+
         Lambda
            delta-lambda const        :  lambda,<min_lambda>,<max_lambda>,<delta_lambda>
            delta-lambda/lambda const : rlambda,<min_lambda>,<max_lambda>,<racio>
-    
+
         Energy            : energy,<min_energy>,<max_energy>,<delta_energy>
-    
+
         Momentum Transfer : q,<min_Q>,<max_Q>,<delta_Q>[,<ki_x>,<ki_y>,<ki_z>]
-    
+
         Energy Transfer   : hw,<Ei>,<min_hw>,<max_hw>,<delta_hw>[,<t0_shift>]
-    
-        d-value           : d,<min_d-val>,<max_d-val>,<delta_d-val>
+
+        d-value
+            delta-d-value                 : d,<min_d-val>,<max_d-val>,<delta_d-val>
+            delta-d-value / d-value const : rd,<min_d-val>,<max_d-val>,<ratio>
 
     -----------------------
     DetParam format
@@ -87,16 +89,16 @@ def GetNeunetHistSAS(runNo="0",HistParam="tof,0,40000,100",DetParam="psd",DetRan
              ptnId = 1 : use shift = p1/(exp(-p2*(lambda-p3)) +p4) + p5*lambda
                          default p1=5.0, p2=8.464, p3=2.08765, p4=1.23477, p5=5.32657
     -----------------------
-    
+
     @param runNo     (string or int) Run Number(s) 123 or "123,124"
-    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw" 
+    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw" "energy" "q" "d" "rd"
     @param DetParam  (string) "DetType[,LLD,HLD]" DetType must be in "psd","n2mon","psd-ph" or "n2mon-ph"
     @param DetRange  (string) "All[:number_of_pixels]" or "startPsdId-endPsdId[:number_of_pixels]"
     @param TimeRange (string) "All" or "startTime,endTime" in [second] or "YYYY/MM/DD,hh:mm:ss,YYYY/MM/DD,hh:mm:ss"
     @param FrameInfo (string) "None" or "FrameNumber, boudaryTime"
     @param MaskInfo  (string) "<maskfile> [,<TOFmask>-<TOFmask>,..]" : if no use maskfile, set "NoFile"
     @param CaseInfo  (string) CaseInfo file must be in ${UTSUSEMI_USR_DIR}/ana/xml or ${UTSUSEMI_HOME_DIR}/ana/xml
-    @param BGInfo    (string) "TimeDep:None" TimeDep:tof1-tof2 
+    @param BGInfo    (string) "TimeDep:None" TimeDep:tof1-tof2
     @param TofShift  (string) "None" or "<ptnId> [,<p1>,<p2>,...]"
     @param AnaMode   (string or int) change analysis mode, which means to swich WiringInfo and DetectorInfo to be used for histogram.
     @param ParamFiles(string) "<path/to/WiringInfo>,<path/to/DetectorInfo>"
@@ -109,6 +111,35 @@ def GetNeunetHistSAS(runNo="0",HistParam="tof,0,40000,100",DetParam="psd",DetRan
         runNoList.append( int(a_run_st) )
     num_of_runs = len(runNoList)
     all_data_list = []
+    if DetRange.find("RPMT") == 0:
+        RPMT_LLDHLD = [0, 0, 0, 0] #[<LLD_X>,<HLD_X>,<LLD_Y>,<HLD_Y>]
+        RPMT_COI = 32 #<LmtCoi>
+
+        #detType="PSD"
+        mode_no=5
+        AnaMode = "5"
+        rpmt_params = DetRange.split(",")
+        if len(rpmt_params)>1:
+            RPMT_LLDHLD[0] = int(rpmt_params[1])
+        if len(rpmt_params)>2:
+            RPMT_LLDHLD[1] = int(rpmt_params[2])
+        if len(rpmt_params)>3:
+            RPMT_LLDHLD[2] = int(rpmt_params[3])
+        if len(rpmt_params)>4:
+            RPMT_LLDHLD[3] = int(rpmt_params[4])
+        if len(rpmt_params)>5:
+            RPMT_LLDHLD[4] = int(rpmt_params[5])
+        if len(rpmt_params)>6:
+            RPMT_COI = int(rpmt_params[6])
+        for a_runNo in runNoList:
+            DaqId = 13 #Default
+            ind = DetRange.find(":")
+            if ind > 0:
+                DaqId = int(DetRange[ind+1:])
+            #ConvertFromRPMTK2Psd( int(a_runNo), DaqId, 0, "SAS03")
+            dfile_found_path = ""
+            HBC.ConvertFromRPMTK2Psd(int(a_runNo), DaqId, 0, "SAS03", mode_no, RPMT_LLDHLD, RPMT_COI, dfile_found_path)
+
     AnaMode = AnaMode+","+ParamFiles
     det_range_list = DetRange.split(",")
     DetRange = ""
@@ -172,12 +203,12 @@ def GetNeunetHistSAS(runNo="0",HistParam="tof,0,40000,100",DetParam="psd",DetRan
             p_chk = mu.UtsusemiCheckDataProcess()
             p_chk.AddProcess( dat, "SolidAngleCorrection" )
             del p_chk
-    
+
     return dat_list
 
 def GetNeunetHistSASWitoutCheckPulseId(runNo="197",HistParam="tof,0,40000,100",DetParam="psd",DetRange="All",TimeRange="All",FrameInfo="None",MaskInfo="NoFile",CaseInfo="None",BGInfo="TimeDep:None",TofShift="None",AnaMode="0",ParamFiles="-,-",SolAngCor=False):
     """
-    Convert Event data of NEUNET to Histogram 
+    Convert Event data of NEUNET to Histogram
     GetNeunetHist(runNo="197,198",
                   HistParam="tof,0,40000,100",
                   DetParam="psd",
@@ -198,21 +229,21 @@ def GetNeunetHistSASWitoutCheckPulseId(runNo="197",HistParam="tof,0,40000,100",D
         TOF
            delta-TOF const :  tof,<min_tof>,<max_tof>,<delta_tof>
            d-TOF/TOF const : rtof,<min_tof>,<max_tof>,<racio>
-       
+
         TOF with time forcusing
            delta-TOF const : tf-tof,<min_tof>,<max_tof>,<delta_tof>
            d-TOF/TOF const : tf-rtof,<min_tof>,<max_tof>,<racio>
-    
+
         Lambda
            delta-lambda const        :  lambda,<min_lambda>,<max_lambda>,<delta_lambda>
            delta-lambda/lambda const : rlambda,<min_lambda>,<max_lambda>,<racio>
-    
+
         Energy            : energy,<min_energy>,<max_energy>,<delta_energy>
-    
+
         Momentum Transfer : q,<min_Q>,<max_Q>,<delta_Q>[,<ki_x>,<ki_y>,<ki_z>]
-    
+
         Energy Transfer   : hw,<Ei>,<min_hw>,<max_hw>,<delta_hw>[,<t0_shift>]
-    
+
         d-value           : d,<min_d-val>,<max_d-val>,<delta_d-val>
 
     -----------------------
@@ -231,23 +262,23 @@ def GetNeunetHistSASWitoutCheckPulseId(runNo="197",HistParam="tof,0,40000,100",D
              ptnId = 1 : use shift = p1/(exp(-p2*(lambda-p3)) +p4) + p5*lambda
                          default p1=5.0, p2=8.464, p3=2.08765, p4=1.23477, p5=5.32657
     -----------------------
-    
+
     @param runNo     (string or int) Run Number(s) 123 or "123,124"
-    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw" 
+    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw"
     @param DetParam  (string) "DetType[,LLD,HLD]" DetType must be in "psd","n2mon","psd-ph" or "n2mon-ph"
     @param DetRange  (string) "All[:number_of_pixels]" or "startPsdId-endPsdId[:number_of_pixels]"
     @param TimeRange (string) "All" or "startTime,endTime" in [second] or "YYYY/MM/DD,hh:mm:ss,YYYY/MM/DD,hh:mm:ss"
     @param FrameInfo (string) "None" or "FrameNumber, boudaryTime"
     @param MaskInfo  (string) "<maskfile> [,<TOFmask>-<TOFmask>,..]" : if no use maskfile, set "NoFile"
     @param CaseInfo  (string) CaseInfo file must be in ${UTSUSEMI_USR_DIR}/ana/xml or ${UTSUSEMI_HOME_DIR}/ana/xml
-    @param BGInfo    (string) "TimeDep:None" TimeDep:tof1-tof2 
+    @param BGInfo    (string) "TimeDep:None" TimeDep:tof1-tof2
     @param TofShift  (string) "None" or "<ptnId> [,<p1>,<p2>,...]"
     @param AnaMode   (string or int) change analysis mode, which means to swich WiringInfo and DetectorInfo to be used for histogram.
     @param ParamFiles(string) "<path/to/WiringInfo>,<path/to/DetectorInfo>"
     @param SolAngCor (bool) True for doing SolidAngle Correction
     @retval DAT (ElementContainerMatrix)
     """
-    
+
     HBC.CheckT0bUpdate(int(runNo))
     AnaMode = AnaMode+","+ParamFiles
     dat_list = BaseCom.GetNeunetHist(runNo,HistParam,DetParam,DetRange,TimeRange,FrameInfo,MaskInfo,CaseInfo,BGInfo,TofShift,AnaMode,Options="ISCHECKPULSEID:false")
@@ -279,7 +310,7 @@ def GetNeunetHistSASWitoutCheckPulseId(runNo="197",HistParam="tof,0,40000,100",D
             p_chk = mu.UtsusemiCheckDataProcess()
             p_chk.AddProcess( dat, "SolidAngleCorrection" )
             del p_chk
-    
+
     return dat_list
 
 ########################################
@@ -304,7 +335,7 @@ def DataReductionMulti( dat_list=DAT,Xrange="4.0 7.7 0.1 dL", kickerNorm=True, i
     run_st=data[0].PutHeader().PutString("RUNNUMBER")
     #runno=int(run_st)
     run_st_list=run_st.split(",")
-    
+
     conv_type =""
     conv_params=""
     p_list=Xrange.split(" ")
@@ -336,7 +367,7 @@ def DataReductionMulti( dat_list=DAT,Xrange="4.0 7.7 0.1 dL", kickerNorm=True, i
             EC_sum += ECs
     EC_sum.PutHeaderPointer().OverWrite("KICKERCOUNT",all_kickers)
     del UCC
-    
+
     lambda_range = "%g %g"%(float(p_list[0]),float(p_list[1]))
 
     #all_kickers = ECs.PutHeaderPointer().PutInt4("KICKERCOUNT")
@@ -356,7 +387,7 @@ def DataReductionMulti( dat_list=DAT,Xrange="4.0 7.7 0.1 dL", kickerNorm=True, i
 ########################################
 def SubtractBackMulti( dat_list=DAT, dat_BG=DAT):
     """
-    
+
     @param dat_list (list of ElementContainerMatrix)
     @param dat_BG (ElementCntainerMatrix)
     @retval DATs (list of ElementContainerMatrix)
@@ -373,16 +404,16 @@ def SubtractBackMulti( dat_list=DAT, dat_BG=DAT):
 ########################################
 def QzProjectionMulti(dat_list=DATList,QxRange="-0.06 0.06 0.001",QyRange="-0.06 0.06 0.001",QzRange="-0.5 0.0",LambdaRange="4.0 7.7 0.01"):
     """
-    
+
     @param dat_list(list)
-    @param Xrange(string) 
+    @param Xrange(string)
     @retval list of ElementContainerArray
     """
     ret = []
     for dat in dat_list:
         eca = QSpace.QzProjection(dat,QxRange,QyRange,QzRange,LambdaRange)
         ret.append(eca)
-    
+
     return ret
 
 ########################################
@@ -390,7 +421,7 @@ def SectorAverageByAnglesMulti( dat_list=DATList, index=0, Banks="SM16-SM14-SD-S
     """
     Convert Data to Q space EventData to produce histogram
     SectorAverageByAngles( dat=DAT, Banks="SM16-SM14-SD-SU", Qrange="0.01 2.0 0.001 dq/Q", LamRange="0.7 0.8", AzimAng="0.0 0.0", PolAng="0.0 0.0" )
-    
+
     @param  dat_list (list of ElementContainerMatrix)
     @param  index    (int)    index number in dat_list to analyze
     @param  Banks    (string)  "SM16-SD-SU" means these banks are unified in one Iq, "SM SD SU" means separated Iq
@@ -401,14 +432,14 @@ def SectorAverageByAnglesMulti( dat_list=DATList, index=0, Banks="SM16-SM14-SD-S
     @param  QLamFile (string)  filename of Q-Lambda range info. If None, no use. (read QLambdaRange_SM.txt for SM bank)
     @retval Iq       (list of ElementContainer)
     """
-    
+
     return QBC.SectorAverageByAngles( dat_list[index], Banks, Qrange, LamRange, AzimAng, PolAng, QLamFile )
 
 ########################################
 def GetAzimuthProfile(dat=DAT, Qcenter=0.036, dQ=0.002, azim_bin=1.0, azim_range="0.0 360.0", lambda_range="0 0"):
     """
     Calculates Azimuth Profile from DataReduction
-    
+
     @param dat          (ElementContainerMatrix)
     @param Qcenter      (float)
     @param dQ           (float)
@@ -424,7 +455,7 @@ def GetAzimuthProfile(dat=DAT, Qcenter=0.036, dQ=0.002, azim_bin=1.0, azim_range
 def GetAzimuthProfileMulti(dat_list=DATList, Qcenter=0.036, dQ=0.002, azim_bin=1.0, azim_range="0.0 360.0", lambda_range="0 0"):
     """
     Calculates Azimuth Profile from DataReduction
-    
+
     @param dat_list     (list)
     @param Qcenter      (float)
     @param dQ           (float)
@@ -438,15 +469,15 @@ def GetAzimuthProfileMulti(dat_list=DATList, Qcenter=0.036, dQ=0.002, azim_bin=1
 ########################################
 def Test( dat_list=DAT, Xrange="0.7 7.6 0.1 dL" ):
     """
-    
+
     @param dat_list(list)
-    @param Xrange(string) 
+    @param Xrange(string)
     @retval list of ElementContainerArray
     """
-    
+
     run_st=dat_list[0].PutHeader().PutString("RUNNUMBER")
     runno=int(run_st)
-    
+
     conv_type =""
     conv_params=""
     p_list=Xrange.split(" ")
@@ -466,7 +497,7 @@ def Test( dat_list=DAT, Xrange="0.7 7.6 0.1 dL" ):
         raise UserWarning("param error about conv type")
 
     ECs = Hist.GetMonHistSAS(runNo=runno,MonNo=1,AxType=conv_type,Xrange=conv_params,MonIndex=0,TimeSlice="-1 -1",frameBoundary=0.0,CalibEffi=True)
-    
+
     lambda_range = "%g %g"%(float(p_list[0]),float(p_list[1]))
     ret = []
     for DATs in dat_list:
@@ -489,15 +520,15 @@ def PickDataByCaseId( dat=DAT, caseId=1 ):
         hh=a_dat.PutHeaderPointer()
         if caseId==hh.PutInt4("CASEID"):
             return a_dat
-    
+
     raise UserWarning("This caseId is NOT included.")
-    
+
 #########################################
 def DoMask(dat=DAT,filename="mask.txt"):
     """
     MASKED flag controled by file.
     @param dat [Def:DAT] (ElementContainerMatrix)
-    @param filename (string) filename of mask information 
+    @param filename (string) filename of mask information
     """
 
     BaseCom.DoMask(dat,filename)
@@ -507,16 +538,16 @@ def RemoveAllMask( dat=DAT ):
     """
     Does remove mask
     REmoveAllMask( dat, filename )
-    
+
     @param dat       (ElementContainerMatrix)
     @param filename  (string) mask file must be in UTSUSEMI_USR_DIR/ana/xml
     @retval None
     """
-    
+
     SMSK = mu.UtsusemiSetMask( dat )
     SMSK.UmaskAll()
     del SMSK
-    
+
 ############################################
 def LoadDataFromManyoBinary(path="./",filename="Sample.mdb"):
     """
@@ -577,7 +608,7 @@ def GetDataFromNeXus(path="./",filename="Sample.nx"):
 def SaveDataToNeXus(dat=DAT, name="Data",path="./",filename="Sample.nx"):
     """
     Save ElementContainer/Array/Matrix to NeXus file.
-    @param  dat       (ElementContainerMatrix)    
+    @param  dat       (ElementContainerMatrix)
     @param  name      (String)   Title of saved data
     @param  path      (String)   path to data file
     @param  filename  (String)  data file name
@@ -608,9 +639,9 @@ def NormByBeamCurrent(dat=DAT,factor=1000.0 ):
 
 
 
-#########################################                                
+#########################################
 def PrintObject(target=PyObj):
-    """ 
+    """
     Print object for debug.
     @param target print to stdout
     @retval None
@@ -621,9 +652,9 @@ def PrintObject(target=PyObj):
     except:
         print("not printable")
 
-#########################################                                
+#########################################
 def MergeDataECM(dat1=DAT, coef1=1.0, dat2=DAT, coef2=0.0, dat3=DAT, coef3=0.0, dat4=DAT, coef4=0.0):
-    """ 
+    """
     Merge Data (ElementContainerMatrix only)
     @param dat1  (ElementContainerMatrix)
     @param coef1 (float) coefficient for dat1
@@ -643,7 +674,7 @@ def MergeDataECM(dat1=DAT, coef1=1.0, dat2=DAT, coef2=0.0, dat3=DAT, coef3=0.0,
         raise UserWarning("dat3 is not ElementContainerMatrix")
     if not isinstance( dat4, Manyo.ElementContainerMatrix ):
         raise UserWarning("dat4 is not ElementContainerMatrix")
-    
+
     ret = dat1.Mul( coef1 )
     hh = ret.PutHeaderPointer()
     if (coef2!=0.0):
@@ -664,7 +695,7 @@ def MergeDataECM(dat1=DAT, coef1=1.0, dat2=DAT, coef2=0.0, dat3=DAT, coef3=0.0,
             hh.OverWrite("BANKIDLIST",bidvect)
             hh.OverWrite("BANKSIZELIST",bszvect)
             hh.OverWrite("BANKNAMELIST",bnmvect)
-            
+
     if (coef3!=0.0):
         for i in range( dat3.PutSize() ):
             ret.Add( dat3.PutPointer(i).Mul(coef3) )
@@ -684,7 +715,7 @@ def MergeDataECM(dat1=DAT, coef1=1.0, dat2=DAT, coef2=0.0, dat3=DAT, coef3=0.0,
             hh.OverWrite("BANKSIZELIST",bszvect)
             hh.OverWrite("BANKNAMELIST",bnmvect)
 
-            
+
     if (coef4!=0.0):
         for i in range( dat4.PutSize() ):
             ret.Add( dat4.PutPointer(i).Mul(coef4) )
@@ -703,7 +734,7 @@ def MergeDataECM(dat1=DAT, coef1=1.0, dat2=DAT, coef2=0.0, dat3=DAT, coef3=0.0,
             hh.OverWrite("BANKIDLIST",bidvect)
             hh.OverWrite("BANKSIZELIST",bszvect)
             hh.OverWrite("BANKNAMELIST",bnmvect)
-    
+
     return ret
 
 ########################################
@@ -998,7 +1029,7 @@ _functions = {
               "SetRPMTMask2thetaByGrav":SetRPMTMask2thetaByGrav,
               "SetRPMTMaskBy2theta":SetRPMTMaskBy2theta
 	      }
-         
+
 _functionsOrder = [
               "GetNeunetHistSAS",
               "DataReductionMulti",
