@@ -480,20 +480,37 @@ PutListOfCounterConditions(){
 //////////////////////////////////////////////////////////
 ElementContainer UtsusemiEventDataConverterNeunetWithPH::
 PutPulseHeightOfDet( ElementContainerMatrix* ecm, UInt4 OuterDetId, UInt4 binSize ){
+    ElementContainer ret;
+    if (PutPulseHeightOfDet(ecm, &ret, binSize)){
+    }else{
+    }
+    return ret;
+}
+//////////////////////////////////////////////////////////
+bool UtsusemiEventDataConverterNeunetWithPH::
+PutPulseHeightOfDet(ElementContainerMatrix* ecm, ElementContainer* retec, UInt4 OuterDetId, UInt4 binSize){
     SearchInHeader *_SIH = new SearchInHeader( ecm );
     _SIH->SearchArray("DetId", OuterDetId );
     std::vector< std::vector<UInt4> > res = _SIH->PutResults();
     delete _SIH;
-
     if (res.empty()){
-        ElementContainer ret;
-        return ret;
+        return false;
     }else
-        return PutPulseHeightOfDet( ecm->PutPointer( res[0][0] ), binSize );
+        return PutPulseHeightOfDet(ecm->PutPointer(res[0][0]), retec, binSize);
 }
 //////////////////////////////////////////////////////////
 ElementContainer UtsusemiEventDataConverterNeunetWithPH::
 PutPulseHeightOfDet( ElementContainerArray* eca, UInt4 binSize ){
+    ElementContainer ec;
+    if (PutPulseHeightOfDet(eca, &ec, binSize)){
+    }else{
+        UtsusemiError(_MessageTag + "Failed PutPulseHeightOfDet");
+    }
+    return ec;
+}
+//////////////////////////////////////////////////////////
+bool UtsusemiEventDataConverterNeunetWithPH::
+PutPulseHeightOfDet(ElementContainerArray* eca, ElementContainer* retec, UInt4 binSize){
 
     std::vector<Int4> ph_vec = eca->PutHeaderPointer()->PutInt4Vector("PulseHeight");
 
@@ -515,24 +532,34 @@ PutPulseHeightOfDet( ElementContainerArray* eca, UInt4 binSize ){
     ev.resize( yv.size(), 0.0 );
     for (UInt4 i=0; i<(yv.size()); i++) ev[i] = sqrt( yv[i] );
 
-    ElementContainer ret;
-    ret.Add("PulseHeight", xv );
-    ret.Add("Counts", yv, "Counts" );
-    ret.Add(UTSUSEMI_KEY_ERROR, ev, "Counts" );
-    ret.SetKeys("PulseHeight","Counts",UTSUSEMI_KEY_ERROR);
-    HeaderBase *hh=ret.PutHeaderPointer();
+    retec->Add("PulseHeight", xv);
+    retec->Add("Counts", yv, "Counts");
+    retec->Add(UTSUSEMI_KEY_ERROR, ev, "Counts");
+    retec->SetKeys("PulseHeight","Counts",UTSUSEMI_KEY_ERROR);
+    HeaderBase *hh=retec->PutHeaderPointer();
     hh->Add("DetId", eca->PutHeaderPointer()->PutInt4(UTSUSEMI_KEY_HEAD_DETID) );
     std::string label = "DetId="+stools->Int4ToString(eca->PutHeaderPointer()->PutInt4(UTSUSEMI_KEY_HEAD_DETID));
     hh->Add(UTSUSEMI_KEY_HEAD_LABEL, label );
-    return ret;
+    return true;
 
 }
 //////////////////////////////////////////////////////////
 ElementContainerArray UtsusemiEventDataConverterNeunetWithPH::
 PutPulseHeightAll( ElementContainerMatrix* ecm, UInt4 binSize ){
     ElementContainerArray eca(ecm->PutHeader());
+    if (PutPulseHeightAll(ecm, &eca, binSize))
+        return eca;
+    else{
+        ElementContainerArray empty;
+        return empty;
+    }
+}
+//////////////////////////////////////////////////////////
+bool UtsusemiEventDataConverterNeunetWithPH::
+PutPulseHeightAll( ElementContainerMatrix* ecm, ElementContainerArray* reteca, UInt4 binSize ){
+    reteca->InputHeader(ecm->PutHeader());
     UInt4 num_of_det= ecm->PutSize();
-    if (num_of_det==0) return eca;
+    if (num_of_det == 0) return false;
     std::vector<UInt4> list_detid;
     bool hasDetId = true;
     for (UInt4 i=0; i<num_of_det; i++){
@@ -546,12 +573,18 @@ PutPulseHeightAll( ElementContainerMatrix* ecm, UInt4 binSize ){
 
     if (hasDetId){
         sort( list_detid.begin(), list_detid.end() );
-        for ( UInt4 i=0; i<list_detid.size(); i++)
-            eca.Add( PutPulseHeightOfDet( ecm, list_detid[i], binSize ) );
+        for (UInt4 i=0; i<list_detid.size(); i++){
+            ElementContainer ec;
+            if (PutPulseHeightOfDet(ecm, &ec, list_detid[i], binSize))
+                reteca->Add(ec);
+        }
     }else{
-        for (UInt4 i=0; i<(ecm->PutSize()); i++)
-            eca.Add( PutPulseHeightOfDet( ecm->PutPointer(i), binSize ) );
+        for (UInt4 i=0; i<(ecm->PutSize()); i++){
+            ElementContainer ec;
+            if (PutPulseHeightOfDet(ecm->PutPointer(i), &ec, binSize))
+                reteca->Add(ec);
+        }
     }
 
-    return eca;
+    return true;
 }
