@@ -1303,7 +1303,8 @@ DumpTrigEventFile( std::string trig_file, std::string out_file, bool isDecorated
     Double clock = 0.0;
     Double first_clock=-1.0;
     if (isDecorated){
-        std::string tmp = "   Time(sec),  TOF(m-sec),  Kicker  ,   Type  [bits]           \n";
+        //                 2025/12/05 03:59:52,      0.000000,  393317.4750, DIO1  Up , LS ADC1 [8388608,0,0,0,0,0,0,0]
+        std::string tmp = "#         Date Time,     Time(sec),   TOF(m-sec),   Trigger, Type [bits]\n";
         ii=std::fwrite( tmp.c_str(), tmp.size(), 1, fout );
     }
     T0TreatToolsNeunet* TT = new T0TreatToolsNeunet();
