@@ -39,7 +39,7 @@ _Initialize(){
     isDEBUG = UtsusemiEnvGetDebugMode();
     //MASKVALUE = 100000000.0;
     MASKVALUE = UTSUSEMIMASKVALUE64;
-    MessageTag = "UtsusemiSqeCalc2 >> ";
+    MessageTag = "UtsusemiSqeCalc2:: ";
     UCC = new UtsusemiUnitConverter();
     isDirectGeometry = true;
 
@@ -584,7 +584,7 @@ _MakeProjectionMatrix( std::vector<Double> rotateSteps, std::vector<Double> view
             for (UInt4 j=0;j<3;j++)
                 va[i*3+j]=viewAxes[i*4+j];
     }else{
-        UtsusemiError(MessageTag+"_MakeProjectionMatrix >>> viewAxes size is invalid.");
+        UtsusemiError(MessageTag + "_MakeProjectionMatrix >>> viewAxes size is invalid. 9 or 16 but given " + stool->Int4ToString((Int4)(viewAxes.size())));
         return false;
     }
     _SetBasisVectToMatrix( va, V);
