@@ -220,7 +220,7 @@ SetDict(){
     tmp->KeyCode = "rtof";
     tmp->NumOfParams.resize(1);
     tmp->NumOfParams[0] = 3;
-    tmp->Memo = "delta-T const. : start_tof, end_tof, racio_of_(dtof/tof)";
+    tmp->Memo = "delta-T const. : start_tof, end_tof, ratio_of_(dtof/tof)";
     tmp->isReversed = false;
     tmp->isRequiredPixelPosi = false;
     tmp->CheckParamsFunc = CheckParamsType003;
@@ -264,7 +264,7 @@ SetDict(){
     tmp->KeyCode = "tf-rtof";
     tmp->NumOfParams.resize(1);
     tmp->NumOfParams[0] = 3;
-    tmp->Memo = "(delta-T)/T const. : start_tof, end_tof, racio_of_(dtof/tof)";
+    tmp->Memo = "(delta-T)/T const. : start_tof, end_tof, ratio_of_(dtof/tof)";
     tmp->isReversed = false;
     tmp->isRequiredPixelPosi = false;
     tmp->CheckParamsFunc = CheckParamsType003;
@@ -377,7 +377,7 @@ SetDict(){
     tmp->KeyCode = "rlambda";
     tmp->NumOfParams.resize(1);
     tmp->NumOfParams[0] = 3;
-    tmp->Memo = "(delta-Lambda)/Lambda const. : start_lam, end_lam, racio_of_(dlamda/lambda)";
+    tmp->Memo = "(delta-Lambda)/Lambda const. : start_lam, end_lam, ratio_of_(dlamda/lambda)";
     tmp->isReversed = false;
     tmp->isRequiredPixelPosi = true;
     tmp->CheckParamsFunc = CheckParamsType024;
@@ -415,6 +415,28 @@ SetDict(){
     if ((tmp->ConvType)>=(Dict.size())) Dict.resize( (tmp->ConvType)+1, NULL );
     Dict[ tmp->ConvType ] = tmp;
 
+    // ConvType = 26 : (delta d) / d const
+    tmp = new WiringInfoConversionTemplate();
+    tmp->ConvType = 26;
+    tmp->KeyCode = "rd";
+    tmp->NumOfParams.resize(1);
+    tmp->NumOfParams[0] = 3;
+    tmp->Memo = "(delta d)/d const : start_d, end_d, ratio_of_(delta-d/d)";
+    tmp->isReversed = false;
+    tmp->isRequiredPixelPosi = true;
+    tmp->CheckParamsFunc = CheckParamsType026;
+    tmp->PutTofFunc = PutTofBinConvType026;
+    tmp->PutXaxisFunc = PutXaxisConvType026;
+    tmp->PutLambdaFunc = PutLambdaConvType026;
+    tmp->LabelsOfEC[0].first = UTSUSEMI_KEY_DVALUE;
+    tmp->LabelsOfEC[0].second = UTSUSEMI_KEY_LAMBDA_UNIT;
+    tmp->LabelsOfEC[1].first = UTSUSEMI_KEY_INTENSITY;
+    tmp->LabelsOfEC[1].second = UTSUSEMI_KEY_COUNTS_UNIT;
+    tmp->LabelsOfEC[2].first = UTSUSEMI_KEY_ERROR;
+    tmp->LabelsOfEC[2].second = UTSUSEMI_KEY_COUNTS_UNIT;
+    if ((tmp->ConvType) >= (Dict.size())) Dict.resize((tmp->ConvType) + 1, NULL);
+    Dict[tmp->ConvType] = tmp;
+
     // ConvType = 27 : inverted geometry (for DNA)
     tmp = new WiringInfoConversionTemplate();
     tmp->ConvType = 27;
@@ -645,7 +667,7 @@ _PutTofBinOrLambda( UInt4 _pixel_id, bool isTof ){
         if (pixel_posi!=NULL)
             out_params.push_back( (_L1 + sqrt((pixel_posi->at(0))*(pixel_posi->at(0)) + (pixel_posi->at(1))*(pixel_posi->at(1)) + (pixel_posi->at(2))*(pixel_posi->at(2)) ))/1000.0 );
 
-    }else if ( (conv_type>=20)&&(conv_type<=25) ){
+    }else if ( (conv_type>=20)&&(conv_type<=26) ){
         out_params.resize( 1 );
         out_params[0] = _L1;
     }
@@ -1559,9 +1581,9 @@ PutXaxisConvType024( std::vector<Double> params, Double tof_offset){
     }else{
         Double lambda_min = params[0];
         Double lambda_max = params[1];
-        Double racio_lambda = params[2];
+        Double ratio_lambda = params[2];
 
-        Double factor = (2.0+racio_lambda)/(2.0-racio_lambda);
+        Double factor = (2.0+ratio_lambda)/(2.0-ratio_lambda);
         if ( lambda_min<=0.0 ) lambda_min = 1.0E-10;
 
         Double first_Lam = 2.0*lambda_min/(1+factor);
@@ -1674,6 +1696,87 @@ PutLambdaConvType025( std::vector<Double>* xaxis, std::vector<Double>* params, s
   return ret;
 }
 
+//////////////////////////////////////////////////////////
+bool WiringInfoConversionDictionary::
+CheckParamsType026( std::vector<Double> params, UtsusemiUnitConverter* uuc ){
+    Double d_min = params[0];
+    Double d_max = params[1];
+    Double d_ratio = params[2];
+
+    if (d_min<0.0){
+        UtsusemiError("WiringInfoConversionDictionary::CheckParamsType026 : invalid param : d_min<0.0");
+        return false;
+    }
+    if (d_min>d_max){
+        UtsusemiError("WiringInfoConversionDictionary::CheckParamsType026 : invalid param : d_min>Q_max");
+        return false;
+    }
+    if (d_ratio<0.0){
+        UtsusemiError("WiringInfoConversionDictionary::CheckParamsType026 : invalid param : d_ratio<0.0");
+        return false;
+    }
+    return true;
+}
+//////////////////////////////////////////////////////////
+std::vector<Double> WiringInfoConversionDictionary::
+PutXaxisConvType026( std::vector<Double> params, Double tof_offset){
+    std::vector<Double> ret;
+    ret.clear();
+    if (params.size()<3){
+        UtsusemiError("WiringInfoConversionDictionary::PutXaxisConvType026 >> Parameters not enough.");
+    }else{
+        Double d_min = params[0];
+        Double d_max = params[1];
+        Double ratio_d = params[2];
+
+        Double factor = (2.0 + ratio_d) / (2.0 - ratio_d);
+        if (d_min <= 0.0) d_min = 1.0E-10;
+
+        // Double first_d = 2.0 * d_min / (1 + faactor);
+        Double first_d = (1.0 - (ratio_d / 2.0)) * d_min;
+        Double currd = first_d;
+        Double i = 1.0;
+        while(currd <= d_max){
+            ret.push_back(currd);
+            currd = first_d * pow(factor, i);
+            i += 1.0;
+        }
+    }
+    return ret;
+}
+//////////////////////////////////////////////////////////
+std::vector<Double> WiringInfoConversionDictionary::
+PutTofBinConvType026( std::vector<Double>* xaxis, std::vector<Double>* params, std::vector<Double>* pv, std::vector<Double>* out_params, UtsusemiUnitConverter* uuc ){
+  std::vector<Double> ret;
+  if ((out_params==NULL)||(out_params->empty())){
+      UtsusemiError("WiringInfoConversionDictionary::PutBinConvType026 >> out_params is invalid.");
+  }else{
+      Double L1 = out_params->at(0);
+      Double L2 = sqrt((pv->at(0)) * (pv->at(0)) + (pv->at(1)) * (pv->at(1)) + (pv->at(2)) * (pv->at(2)));
+      Double theta = acos((pv->at(2)) / L2) / 2.0;
+      Double const_dToTof = 2.0 * sin(theta) * ((L1 + L2) / 1000.0) / (uuc->VtoLambda());
+      ret.resize(xaxis->size(), 0.0);
+      for (UInt4 i=0; i<ret.size(); i++)
+          ret[i] = (xaxis->at(i)) * const_dToTof;
+  }
+  return ret;
+}
+//////////////////////////////////////////////////////////
+std::vector<Double> WiringInfoConversionDictionary::
+PutLambdaConvType026( std::vector<Double>* xaxis, std::vector<Double>* params, std::vector<Double>* pv, std::vector<Double>* out_params, UtsusemiUnitConverter* uuc ){
+  std::vector<Double> ret;
+  if ((out_params==NULL)||(out_params->empty())){
+      UtsusemiError("WiringInfoConversionDictionary::PutLambdaConvType026 >> out_params is invalid.");
+  }else{
+      Double L2 = sqrt((pv->at(0)) * (pv->at(0)) + (pv->at(1)) * (pv->at(1)) + (pv->at(2)) * (pv->at(2)));
+      Double theta = acos((pv->at(2)) / L2) / 2.0;
+      ret.resize(xaxis->size(), 0.0);
+      for (UInt4 i=0; i<ret.size(); i++)
+          ret[i] = 2.0 * (xaxis->at(i)) * sin(theta);
+  }
+  return ret;
+}
+
 
 
 //////////////////////////////////////////////////////////
