@@ -71,7 +71,9 @@ def GetNeunetHist(runNo="197", HistParam="tof,0,40000,100", DetParam="psd", DetR
 
         Energy Transfer   : hw,<Ei>,<min_hw>,<max_hw>,<delta_hw>[,<t0_shift>]
 
-        d-value           : d,<min_d-val>,<max_d-val>,<delta_d-val>
+        d-value
+            delta-d-value                 : d,<min_d-val>,<max_d-val>,<delta_d-val>
+            delta-d-value / d-value const : rd,<min_d-val>,<max_d-val>,<ratio>
 
     -----------------------
     DetParam format
@@ -100,7 +102,7 @@ def GetNeunetHist(runNo="197", HistParam="tof,0,40000,100", DetParam="psd", DetR
              "SZ"               "2.0"     [mm]      Set z axis of sample position
 
     @param runNo     (string) Run Numbers
-    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw"
+    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw" "energy" "q" "d" "rd"
     @param DetParam  (string) "DetType[LLD:HLD]" DetType must be in "psd","n2mon","psd-ph" or "n2mon-ph"
     @param DetRange  (string) "All[:number_of_pixels]" or "startPsdId-endPsdId[:number_of_pixels]"
     @param TimeRange (string) "All" or "startTime,endTime" in [second] or "YYYY/MM/DD,hh:mm:ss,YYYY/MM/DD,hh:mm:ss"
@@ -819,6 +821,41 @@ def TofToEnergyTransferStrict(dat=DAT, Ei=-1.0, L1=30.0, t0shift=0.0, Emin=-10.0
     mu.UtsusemiMessage('Cmm.TofToEnergyTransferStrict(<ElementContainerMatrix>,{},{},{},{},{},{})'.format(
         Ei, L1, t0shift, Emin, Emax, deltaE), True)
     BaseCom.TofToEnergyTransferStrict(dat, Ei, L1, t0shift, Emin, Emax, deltaE)
+##########################################
+
+
+def RadialCollimatorCorrect(dat=DAT, vdat=DAT, integRange="All", pixelRange="All"):
+    """
+    Data Correction for radial collimator on AMR
+
+    @param dat [Def:DAT] (ElementContainerMatrix) Target data
+    @param vdat [Def:DAT] (ElementContainerMatrix) Vanadium data
+    @param integRange (string) Integrate range "All" or "<start>:<end>"
+    @param pixelRange (string) Pixel range to be used "All" or "<start>:<end>"
+    @retval None
+    """
+    mu.UtsusemiMessage('Cmm.RadialCollimatorCorrect(<EleemntContainerMatrix>,<EleemntContainerMatrix>,{},{}'.format(
+        integRange, pixelRange), True)
+    BaseCom.RadialCollimatorCorrectSIK(dat, vdat, integRange, pixelRange)
+
+##########################################
+
+
+def RadialCollimatorCorrectByFile(dat=DAT, path="./", filename="vdata.mbd", integRange="All", pixelRange="All"):
+    """
+    Data Correction for radial collimator
+
+    @param dat [Def:DAT] (ElementContainerMatrix) Target data
+    @param path (string) directory path storing vanadium data
+    @param filename (string) fine name of vanadium data
+    @param integRange (string) Integrate range "All" or "<start>:<end>"
+    @param pixelRange (string) Pixel range to be used "All" or "<start>:<end>"
+    @retval None
+    """
+    mu.UtsusemiMessage('Cmm.RadialCollimatorCorrectByFile(<EleemntContainerMatrix>,{},{},{},{}'.format(
+        path, filename, integRange, pixelRange), True)
+    vdat = LoadDataFromManyoBinary(path, filename)
+    BaseCom.RadialCollimatorCorrectSIK(dat, vdat, integRange, pixelRange)
 
 #########################################
 
@@ -969,7 +1006,9 @@ _functions = {
     "SaveDataToSrlz": SaveDataToSrlz,
     "LoadDataFromSrlz": LoadDataFromSrlz,
     "TofToEnergyTransfer": TofToEnergyTransfer,
-    "TofToEnergyTransferStrict": TofToEnergyTransferStrict
+    "TofToEnergyTransferStrict": TofToEnergyTransferStrict,
+    "RadialCollimatorCorrect": RadialCollimatorCorrect,
+    "RadialCollimatorCorrectByFile": RadialCollimatorCorrectByFile
 }
 _functionsOrder = [
     "CopyData",
@@ -1001,6 +1040,8 @@ _functionsOrder = [
     "GetPH",
     "NormByBeam",
     "getBeamCurrent",
+    "RadialCollimatorCorrect",
+    "RadialCollimatorCorrectByFile",
     "SaveDataToNxspe",
     "LoadDataFromNxspe",
     "SaveDataToSPE",
