@@ -72,7 +72,9 @@ def GetNeunetHist(runNo="197", HistParam="tof,0,40000,100", DetParam="psd", DetR
 
         Energy Transfer   : hw,<Ei>,<min_hw>,<max_hw>,<delta_hw>[,<t0_shift>]
 
-        d-value           : d,<min_d-val>,<max_d-val>,<delta_d-val>
+        d-value
+            delta-d-value                 : d,<min_d-val>,<max_d-val>,<delta_d-val>
+            delta-d-value / d-value const : rd,<min_d-val>,<max_d-val>,<ratio>
 
     -----------------------
     DetParam format
@@ -101,7 +103,7 @@ def GetNeunetHist(runNo="197", HistParam="tof,0,40000,100", DetParam="psd", DetR
              "SZ"               "2.0"     [mm]      Set z axis of sample position
 
     @param runNo     (string) Run Numbers
-    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw"
+    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw" "energy" "q" "d" "rd"
     @param DetParam  (string) "DetType[LLD:HLD]" DetType must be in "psd","n2mon","psd-ph" or "n2mon-ph"
     @param DetRange  (string) "All[:number_of_pixels]" or "startPsdId-endPsdId[:number_of_pixels]"
     @param TimeRange (string) "All" or "startTime,endTime" in [second] or "YYYY/MM/DD,hh:mm:ss,YYYY/MM/DD,hh:mm:ss"
