@@ -154,7 +154,9 @@ def GetNeunetHist(runNo="197", HistParam="tof,0,40000,100", DetParam="psd", DetR
 
         Energy Transfer   : hw,<Ei>,<min_hw>,<max_hw>,<delta_hw>[,<t0_shift>]
 
-        d-value           : d,<min_d-val>,<max_d-val>,<delta_d-val>
+        d-value
+            delta-d-value                 : d,<min_d-val>,<max_d-val>,<delta_d-val>
+            delta-d-value / d-value const : rd,<min_d-val>,<max_d-val>,<ratio>
 
     -----------------------
     DetParam format
@@ -183,7 +185,7 @@ def GetNeunetHist(runNo="197", HistParam="tof,0,40000,100", DetParam="psd", DetR
              "SZ"               "2.0"     [mm]      Set z axis of sample position
 
     @param runNo     (string or int) Run Number(s) 123 or "123,124"
-    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw"
+    @param HistParam (string) "type,param,param,param,..." type must be in "tof" "rtof" "lambda" "rlambda" "hw" "energy" "q" "d" "rd"
     @param DetParam  (string) "DetType[LLD:HLD]" DetType must be in "psd","n2mon","psd-ph" or "n2mon-ph"
     @param DetRange  (string) "All[:number_of_pixels]" or "startPsdId-endPsdId[:number_of_pixels]"
     @param TimeRange (string) "All" or "startTime,endTime" in [second] or "YYYY/MM/DD,hh:mm:ss,YYYY/MM/DD,hh:mm:ss"
@@ -486,7 +488,11 @@ def AverageAll(dat, maskfile="None"):
         DoMask(dat, maskfile)
 
     AVC = mm.AverageElementContainerMatrix(dat)
-    ec = AVC.GetAverage()
+    ec = Manyo.ElementContainer()
+    if AVC.GetAverage(ec):
+        pass
+    else:
+        raise UserWarning("AverageAll >> Failed GetAverage.")
     del AVC
     return ec
 
@@ -508,7 +514,11 @@ def GetPH(dat, binSize=1):
         raise UserWarning("This Data has no Pulse Height info")
 
     ev_ph = mu.UtsusemiEventDataConverterNeunetWithPH()
-    return ev_ph.PutPulseHeightAll(dat, binSize)
+    ret_eca = Manyo.ElementContainerArray()
+    if ev_ph.PutPulseHeightAll(dat, ret_eca, binSize):
+        return ret_eca
+    else:
+        raise UserWarning("Failed PutPulseHeightAll")
 
 #########################################
 
@@ -912,10 +922,17 @@ def IntegPixels(Target, PSD_min=1, PSD_max=1, Pixel_min=1, Pixel_max=1, isAve=Tr
                 detv.append(psdv[i])
                 pixv.append(int(j))
         AVE = mm.AverageElementContainerMatrix(Target, detv, pixv)
+        EC = Manyo.ElementContainer()
         if isAve:
-            EC = AVE.GetAverage()
+            if AVE.GetAverage(EC):
+                pass
+            else:
+                raise UserWarning("IntegPixels ERROR")
         else:
-            EC = AVE.GetSum()
+            if AVE.GetSum(EC):
+                pass
+            else:
+                raise UserWarning("IntegPixels ERROR")
         del AVE
 
     # Add Header Info
