@@ -1321,8 +1321,9 @@ class MapFrame(QtWidgets.QMainWindow):
         self.cursol = self.fig.add_subplot(111, frameon=False)
         self.cursol.set_position([0.08, 0.15, 0.89, 0.73])
 
-        self.cursol.sharex(self.ax)
-        self.cursol.sharey(self.ax)
+        if matplotlib_verNo >= 3030:
+            self.cursol.sharex(self.ax)
+            self.cursol.sharey(self.ax)
 
         # マスクデータの色作成(白色)
         # cmap = cm.jet
@@ -1479,10 +1480,12 @@ class MapFrame(QtWidgets.QMainWindow):
         if self.dragFlag:
             # カーソル用サブプロットをクリア
             self.cursol.clear()
-            self.cursol.sharex(self.ax)
-            self.cursol.sharey(self.ax)
-            #self.cursol.set_xlim(self.ax.get_xlim())
-            #self.cursol.set_ylim(self.ax.get_ylim())
+            if matplotlib_verNo >= 3030:
+                self.cursol.sharex(self.ax)
+                self.cursol.sharey(self.ax)
+            else:
+                self.cursol.set_xlim(self.ax.get_xlim())
+                self.cursol.set_ylim(self.ax.get_ylim())
 
             # if version of matplotlib > 0.98
             if matplotlib_verNo > 980:
@@ -1632,10 +1635,12 @@ class MapFrame(QtWidgets.QMainWindow):
 
             # Cursor面をクリアしたのちは必ず再設定が必要
             self.cursol.clear()
-            self.cursol.sharex(self.ax)
-            self.cursol.sharey(self.ax)
-            #self.cursol.set_xlim(self.ax.get_xlim())
-            #self.cursol.set_ylim(self.ax.get_ylim())
+            if matplotlib_verNo >= 3030:
+                self.cursol.sharex(self.ax)
+                self.cursol.sharey(self.ax)
+            else:
+                self.cursol.set_xlim(self.ax.get_xlim())
+                self.cursol.set_ylim(self.ax.get_ylim())
             if matplotlib_verNo > 980:
                 self.cursol.autoscale(False)
             self.cursol.set_xticks([])
