@@ -37,7 +37,58 @@ AdvScatAbsoBodyManagerMLF:: AdvScatAbsoBodyManagerMLF(void){
 
     //atomicDataFile="/home/dnaadmin/ana/setup/database/all_nist_data.dat";
     // #[inamura 190322] put "all_nist_data.dat" into MLF/database
+    atomicDataFile = "";
     const char *manyo_path_c = getenv("MANYO_PATH");
+    const char *mlfsoft_path_c = getenv("MLFSOFT_PATH");
+    std::string manyo_path = "";
+    std::string mlfsoft_path = "";
+    if (manyo_path_c != NULL){
+        std::string tmp(manyo_path_c);
+        manyo_path = tmp;
+    }
+    if (mlfsoft_path_c != NULL){
+        std::string tmp(mlfsoft_path_c);
+        mlfsoft_path = tmp;
+    }
+    std::string atomic_data_file = "";
+    if (manyo_path != ""){
+        char target_path_c[400];
+        std::snprintf(target_path_c, sizeof(target_path_c), "%s/share/Manyo/MLF/database/all_nist_data.dat",manyo_path.c_str());
+        std::fstream foAtomicData(target_path_c, std::ios::in);
+        if (!(foAtomicData.fail())) atomic_data_file = (std::string)target_path_c;
+        else{
+            std::cout << "WARNING : AdvScatAbsoBodyManagerMLF constructer >> not found (" << (std::string)target_path_c << ") " << std::endl;
+            foAtomicData.close();
+        }
+    }
+    if ((atomic_data_file == "") && (mlfsoft_path != "")){
+        char target_path_c[400];
+        std::snprintf(target_path_c, sizeof(target_path_c), "%s/share/Manyo/MLF/database/all_nist_data.dat",mlfsoft_path.c_str());
+        std::fstream foAtomicData(target_path_c, std::ios::in);
+        if (!(foAtomicData.fail())) atomic_data_file = (std::string)target_path_c;
+        else {
+            std::cout << "WARNING : AdvScatAbsoBodyManagerMLF constructer >> not found (" << (std::string)target_path_c << ") " << std::endl;
+            foAtomicData.close();
+        }
+    }
+    if ((atomic_data_file == "") && (manyo_path != "")){
+        char target_path_c[400];
+        std::snprintf(target_path_c, sizeof(target_path_c), "%s/../../../share/Manyo/MLF/database/all_nist_data.dat",manyo_path.c_str());
+        std::fstream foAtomicData(target_path_c, std::ios::in);
+        if (!(foAtomicData.fail())) atomic_data_file = (std::string)target_path_c;
+        else {
+            std::cout << "WARNING : AdvScatAbsoBodyManagerMLF constructer >> not found (" << (std::string)target_path_c << ") " << std::endl;
+            foAtomicData.close();
+        }
+    }
+    if (atomic_data_file == ""){
+        std::cerr << "WARNING :: AdvScatAbsoBodyManagerMlf::constructor >> not found atomic data file." << std::endl;
+    }else{
+        atomicDataFile = atomic_data_file;
+        std::cout << "AdvScatAbsoBodyManagerMlf::constructor >> found atomic data file = " << atomicDataFile << std::endl;
+    }
+    // std::cout << "#[inamura 251008] AdvScatAbsoBodyManagerMlf constructor >> atomicDataFile = " << atomicDataFile << std::endl;
+    /*
     if (manyo_path_c!=NULL){
         std::string manyo_path( manyo_path_c );
         if (manyo_path!=""){
@@ -46,11 +97,11 @@ AdvScatAbsoBodyManagerMLF:: AdvScatAbsoBodyManagerMLF(void){
             std::string atomic_data_file( target_path_c );
             atomicDataFile = atomic_data_file;
         }
-    }
+    } */
 
     if (SearchDataBase()){
     }else{
-        std::cerr << "AdvScatAbsoBodyManagerMLF::AdvScatAbsoBodyManagerMLF(void) >> atomic datapath is not found " << std::endl;
+        std::cerr << "ERROR :: AdvScatAbsoBodyManagerMLF constructure >> atomic datapath is not found " << std::endl;
     }
     //std::cout << "atomic_datapath(default) = " << atomicDataFile << std::endl; [151008 inamura]
 
@@ -81,26 +132,28 @@ AdvScatAbsoBodyManagerMLF:: AdvScatAbsoBodyManagerMLF(std::string filepath){
 /////////////////////////////////////////////////////////////////////////////////////////////
 bool AdvScatAbsoBodyManagerMLF:: SearchDataBase(){
     std::fstream fo(atomicDataFile.c_str(), std::ios::in);
-    char target_path_c[400];
-    if(fo.fail()){
-        std::string basename("all_nist_data.dat");
-        const char *home_path_c = getenv("HOME");
-        if (home_path_c!=NULL){
-            std::string home_path( home_path_c);
-            if (home_path!=""){
-                std::snprintf( target_path_c, sizeof(target_path_c), "%s/ana/setup/database/%s",home_path.c_str(),basename.c_str() );
-                std::fstream fo2(target_path_c, std::ios::in);
-                if (fo2.fail()) return false;
+    if(!(fo.fail())){
+        fo.close();
+        return true;
+    }
 
+    std::string basename("all_nist_data.dat");
+    const char *home_path_c = getenv("HOME");
+    char target_path_c[400];
+    if (home_path_c!=NULL){
+        std::string home_path( home_path_c);
+        if (home_path!=""){
+            std::snprintf( target_path_c, sizeof(target_path_c), "%s/ana/setup/database/%s",home_path.c_str(),basename.c_str() );
+            std::fstream fo2(target_path_c, std::ios::in);
+            if (!(fo2.fail())){
                 atomicDataFile = target_path_c;
                 fo2.close();
                 return true;
             }
         }
-    }else{
-        fo.close();
-        return true;
     }
+
+    atomicDataFile = "";
     return false;
 }
 /////////////////////////////////////////////////////////////////////////////////////////////
@@ -729,3 +782,22 @@ void AdvScatAbsoBodyManagerMLF:: DeleteXsDataObject(void){
   }
   delete dataCS;
 }
+
+/**
+ * check whether an atomic data file can be loaded correctly or not.
+ *
+ */
+bool AdvScatAbsoBodyManagerMLF:: isFoundAtomicDataFile(){
+  if (atomicDataFile == "") return false;
+  else return true;
+}
+
+/**
+ * check whether functions can work (initialization succeeded) or not
+ */
+bool AdvScatAbsoBodyManagerMLF:: isReady(){
+  bool isReady = true;
+  isReady = isFoundAtomicDataFile();
+
+  return isReady;
+}
